==> elki_0.5.0.orig.tar.bz2: elki-0.5.0/src/de/lmu/ifi/dbs/elki/utilities/datastructures/arraylike/SubsetArrayAdapter.java <==
package de.lmu.ifi.dbs.elki.utilities.datastructures.arraylike;
/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2012
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Subset array adapter (allows reordering and projection)
 * 
 * @author Erich Schubert
 *
 * @param <T> Entry type
 * @param <A> Array type
 */
public class SubsetArrayAdapter<T, A> implements ArrayAdapter<T, A> {
  /**
   * Wrapped adapter
   */
  ArrayAdapter<T, ? super A> wrapped;

  /**
   * Offsets to return
   */
  int[] offs;
  
  /**
   * Constructor.
   *
   * @param wrapped Wrapped adapter
   * @param offs Offsets
   */
  public SubsetArrayAdapter(ArrayAdapter<T, ? super A> wrapped, int[] offs) {
    super();
    this.wrapped = wrapped;
    this.offs = offs;
  }

  @Override
  public int size(A array) {
    return offs.length;
  }

  @Override
  public T get(A array, int off) throws IndexOutOfBoundsException {
    return wrapped.get(array, offs[off]);
  }
}

==> elki_0.5.5.orig.tar.bz2: elki-0.5.5/src/de/lmu/ifi/dbs/elki/utilities/datastructures/arraylike/SubsetArrayAdapter.java <==
package de.lmu.ifi.dbs.elki.utilities.datastructures.arraylike;
/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2012
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Subset array adapter (allows reordering and projection).
 * 
 * @author Erich Schubert
 *
 * @param <T> Entry type
 * @param <A> Array type
 */
public class SubsetArrayAdapter<T, A> implements ArrayAdapter<T, A> {
  /**
   * Wrapped adapter.
   */
  ArrayAdapter<T, ? super A> wrapped;

  /**
   * Offsets to return.
   */
  int[] offs;
  
  /**
   * Constructor.
   *
   * @param wrapped Wrapped adapter
   * @param offs Offsets
   */
  public SubsetArrayAdapter(ArrayAdapter<T, ? super A> wrapped, int[] offs) {
    super();
    this.wrapped = wrapped;
    this.offs = offs;
  }

  @Override
  public int size(A array) {
    return offs.length;
  }

  @Override
  public T get(A array, int off) throws IndexOutOfBoundsException {
    return wrapped.get(array, offs[off]);
  }
}
